@@ -15,8 +15,6 @@ if TYPE_CHECKING:
     from pydantic_ai.toolsets import AbstractToolset
 
     ToolOrCallable = Tool | Callable
-else:
-    ToolOrCallable = Any
 
 
 def create_sub_agent_tool(
@@ -25,28 +23,41 @@ def create_sub_agent_tool(
     system_prompt: str | None = None,
     model: "str | Model | None" = None,
     model_settings: "ModelSettings | None" = None,
-    tools: list[ToolOrCallable] = [],
+    tools: "list[ToolOrCallable]" = [],
     toolsets: list["AbstractToolset[Agent]"] = [],
     is_yolo_mode: bool | None = None,
 ) -> Callable[[AnyContext, str], Coroutine[Any, Any, str]]:
     """
-    Creates a "tool that is another AI agent," capable of handling complex, multi-step sub-tasks.
+    Creates a "tool that is another AI agent," capable of handling complex,
+    multi-step sub-tasks.
 
-    This powerful factory function generates a tool that, when used, spins up a temporary, specialized AI agent. This "sub-agent" has its own system prompt, tools, and context, allowing it to focus exclusively on accomplishing the task it's given without being distracted by the main conversation.
+    This powerful factory function generates a tool that, when used, spins up
+    a temporary, specialized AI agent. This "sub-agent" has its own system
+    prompt, tools, and context, allowing it to focus exclusively on
+    accomplishing the task it's given without being distracted by the main
+    conversation.
 
-    This is ideal for delegating complex tasks like analyzing a file or a repository.
+    This is ideal for delegating complex tasks like analyzing a file or a
+    repository.
 
     Args:
         tool_name (str): The name for the generated sub-agent tool.
-        tool_description (str): A clear description of the sub-agent's purpose and when to use it.
-        system_prompt (str, optional): The system prompt that will guide the sub-agent's behavior.
-        model (str | Model, optional): The language model the sub-agent will use.
-        model_settings (ModelSettings, optional): Specific settings for the sub-agent's model.
-        tools (list, optional): A list of tools that will be exclusively available to the sub-agent.
+        tool_description (str): A clear description of the sub-agent's purpose
+            and when to use it.
+        system_prompt (str, optional): The system prompt that will guide the
+            sub-agent's behavior.
+        model (str | Model, optional): The language model the sub-agent will
+            use.
+        model_settings (ModelSettings, optional): Specific settings for the
+            sub-agent's model.
+        tools (list, optional): A list of tools that will be exclusively
+            available to the sub-agent.
         toolsets (list, optional): A list of Toolset for the sub-agent.
 
     Returns:
-        Callable: An asynchronous function that serves as the sub-agent tool. When called, it runs the sub-agent with a given query and returns its final result.
+        Callable: An asynchronous function that serves as the sub-agent tool.
+            When called, it runs the sub-agent with a given query and returns
+            its final result.
     """
 
     async def run_sub_agent(ctx: AnyContext, query: str) -> str:
@@ -97,7 +108,8 @@ def create_sub_agent_tool(
             ctx=ctx,
             agent=sub_agent_agent,
             user_prompt=query,
-            history_list=[],  # Start with empty history for the sub-agent
+            attachments=[],
+            history_list=[],
         )
 
         # Return the sub-agent's final message content
